@@ -21,7 +21,6 @@
  */
 
 #include "dialog.h"
-#include <QDebug>
 
 /*!
  * \brief DialogView constructor.
@@ -32,10 +31,15 @@ DialogView::DialogView(DialogView::Type type, QString message, QGraphicsWidget *
 {
     this->setGeometry(0,0,800,480);
 
+    _exposeButton = new TwitterButton(TwitterButton::Expose,"",this);
+    _exposeButton->setPos(0,0);
+    _exposeButton->setZValue(2.0);
+
     /* Dark Background */
     m_background = new QGraphicsRectItem(QRectF(0,0,800,480),this);
     m_background->setOpacity(0.5);
     m_background->setZValue(1.0);
+    m_background->setBrush(Qt::black);
 
     /* White Rectangle */
     QGraphicsPixmapItem *box = new QGraphicsPixmapItem(this);
@@ -51,43 +55,44 @@ DialogView::DialogView(DialogView::Type type, QString message, QGraphicsWidget *
 
     QGraphicsTextItem *text = new QGraphicsTextItem(this);
     text->setHtml(_message);
+    text->setDefaultTextColor(QColor(0,0,0));
     text->setTextWidth(386);
     text->setPos(box->pos().x() + 32, box->pos().y() + 88);
     text->setZValue(3.0);
 
     switch(_type) {
         case Error:
-            _yesButton = new TwitterButton(TwitterButton::Generic, "Ok", this);
-            _yesButton ->setPos((box->boundingRect().width() - _yesButton->boundingRect().width())/2
+            _button1 = new TwitterButton(TwitterButton::Generic, "Ok", this);
+            _button1 ->setPos((box->boundingRect().width() - _button1->boundingRect().width())/2
                                 + box->pos().x(), box->boundingRect().height() - 20);
-            _yesButton->setZValue(3.0);
+            _button1->setZValue(3.0);
             break;
 
         case Warning:
-            _yesButton = new TwitterButton(TwitterButton::Generic, "Yes", this);
-            _yesButton->setPos((box->boundingRect().width()/2 - _yesButton->boundingRect().width())/2
+            _button1 = new TwitterButton(TwitterButton::Generic, "Yes", this);
+            _button1->setPos((box->boundingRect().width()/2 - _button1->boundingRect().width())/2
                                + box->pos().x(), box->boundingRect().height() - 20);
-            _yesButton->setZValue(3.0);
+            _button1->setZValue(3.0);
 
-            _noButton = new TwitterButton(TwitterButton::Generic, "No", this);
-            _noButton->setPos((box->boundingRect().width()/2 - _noButton->boundingRect().width())/2
+            _button2 = new TwitterButton(TwitterButton::Generic, "No", this);
+            _button2->setPos((box->boundingRect().width()/2 - _button2->boundingRect().width())/2
                               + box->pos().x() + box->boundingRect().width()/2, box->boundingRect().height() - 20);
-            _noButton->setZValue(3.0);
+            _button2->setZValue(3.0);
             break;
 
         case Location:
-            _ipButton = new TwitterButton(TwitterButton::Generic, "IP", this);
-            _ipButton->setPos((box->boundingRect().width()/3 - _ipButton->boundingRect().width())/2
+            _button1 = new TwitterButton(TwitterButton::Generic, "IP", this);
+            _button1->setPos((box->boundingRect().width()/3 - _button1->boundingRect().width())/2
                               + box->pos().x() + 32, box->boundingRect().height() - 20);
-            _ipButton->setZValue(3.0);
+            _button1->setZValue(3.0);
 
-            _gpsButton = new TwitterButton(TwitterButton::Generic, "GPS", this);
-            _gpsButton->setPos(_ipButton->pos().x() + box->boundingRect().width()/3 - 32, box->boundingRect().height() - 20);
-            _gpsButton->setZValue(3.0);
+            _button2 = new TwitterButton(TwitterButton::Generic, "GPS", this);
+            _button2->setPos(_button1->pos().x() + box->boundingRect().width()/3 - 32, box->boundingRect().height() - 20);
+            _button2->setZValue(3.0);
 
-            _cancelButton = new TwitterButton(TwitterButton::Generic, "Cancel", this);
-            _cancelButton->setPos(_gpsButton->pos().x() + box->boundingRect().width()/3 -32, box->boundingRect().height() - 20);
-            _cancelButton->setZValue(3.0);
+            _button3 = new TwitterButton(TwitterButton::Generic, "Cancel", this);
+            _button3->setPos(_button2->pos().x() + box->boundingRect().width()/3 -32, box->boundingRect().height() - 20);
+            _button3->setZValue(3.0);
             break;
     }
 
@@ -98,36 +103,27 @@ void DialogView::createConnects(void)
 {
     switch(_type) {
         case Warning:
-            connect(_noButton, SIGNAL(released()), this, SLOT(buttonPressed()));
-            connect(_noButton, SIGNAL(released()), this, SIGNAL(noPressed()));
+            connect(_button2, SIGNAL(released()), this, SLOT(buttonPressed()));
+            connect(_button2, SIGNAL(released()), this, SIGNAL(noPressed()));
 
         case Error:
-            connect(_yesButton, SIGNAL(released()), this, SLOT(buttonPressed()));
-            connect(_yesButton, SIGNAL(released()), this, SIGNAL(yesPressed()));
+            connect(_button1, SIGNAL(released()), this, SLOT(buttonPressed()));
+            connect(_button1, SIGNAL(released()), this, SIGNAL(yesPressed()));
             break;
 
         case Location:
-            connect(_ipButton, SIGNAL(released()), this, SIGNAL(getIP()));
-            connect(_ipButton, SIGNAL(released()), this, SLOT(buttonPressed()));
+            connect(_button1, SIGNAL(released()), this, SIGNAL(getIP()));
+            connect(_button1, SIGNAL(released()), this, SLOT(buttonPressed()));
 
-            connect(_gpsButton, SIGNAL(released()), this, SIGNAL(getGPS()));
-            connect(_gpsButton, SIGNAL(released()), this, SLOT(buttonPressed()));
+            connect(_button2, SIGNAL(released()), this, SIGNAL(getGPS()));
+            connect(_button2, SIGNAL(released()), this, SLOT(buttonPressed()));
 
-            connect(_cancelButton, SIGNAL(released()), this, SIGNAL(cancelPressed()));
-            connect(_cancelButton, SIGNAL(released()), this, SLOT(buttonPressed()));
+            connect(_button3, SIGNAL(released()), this, SIGNAL(cancelPressed()));
+            connect(_button3, SIGNAL(released()), this, SLOT(buttonPressed()));
             break;
     }
 }
 
-/*!
- * \brief Set message
- * \param String to message of dialog
- */
-void DialogView::setMessage(const QString &message)
-{
-    _message = message;
-}
-
 /*!
  * \brief Implement the button pressed event
  * */
