@@ -286,6 +286,12 @@ void LineEdit::setMessage(QString message)
     }
 }
 
+void LineEdit::clearText(void)
+{
+    setMessage("");
+    lostFocus();
+}
+
 /*!
  * \brief This function enables or disables a line edit.
  * \param option true to enable and false to disable line edit.
