@@ -32,14 +32,6 @@ LoginView::LoginView(void)
     _exitAnim = 0;
 }
 
-/*!
- * \brief LoginView destructor.
- */
-LoginView::~LoginView()
-{
-    qDebug() << "DELETED LoginView object : ";
-}
-
 /*!
  * \brief Creates the LoginView objects and animations.
  */
@@ -47,34 +39,24 @@ void LoginView::createUi(void)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
     _createLoginBackground();
-    _createEntries();
-    _createLabels();
-    _createCheckbox();
     _createButtons();
     _createLogo();
+    _createSettings();
+    _createOauthWizard();
+    _createUsersList();
 
     /* Animations */
     _entryAnim = _createEntryAnimation();
     _entryAnim->start();
     _exitAnim = _createExitAnimation();
 
-
     connect(qobject_cast<QObject *>(_exitAnim), SIGNAL(finished()), this,
-            SLOT(_exitAnimationFinished()));
+            SIGNAL(done()));
     connect(_exitButton, SIGNAL(released()), this, SIGNAL(exitLogin()));
-    connect(_loginButton, SIGNAL(released()), this, SLOT(_emitLoginAccount()));
-    connect(checkbox,SIGNAL(pressed()),this,SLOT(_checked()));
-    connect(_entryPassword, SIGNAL(enterPressed()), this, SLOT(_emitLoginAccount()));
+    connect(_loginButton, SIGNAL(released()), this, SLOT(emitLoginAccount()));
+    connect(_settingsButton, SIGNAL(released()), this, SLOT(_animSettings()));
     connect(_cancelButton, SIGNAL(released()), this, SLOT(_endLogin()));
-}
-
-/*!
- * \brief Emits exit animation signal.
- */
-void LoginView::_exitAnimationFinished(void)
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    emit done();
+    connect(_newAccountButton, SIGNAL(released()), _oauthWizard, SLOT(startAnimation()));
 }
 
 /*!
@@ -85,50 +67,27 @@ QAbstractAnimation *LoginView::_createEntryAnimation(void)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
     QParallelAnimationGroup *anim = new QParallelAnimationGroup(this);
-    /* Delay time for each animation (milliseconds) */
-    int delay = 100;
 
     QEasingCurve easingCurve;
-    easingCurve.setType(QEasingCurve::OutCirc);
-
-    /* Buttons */
-    _addOpacityAnim(anim, _loginButton, 0);
-    _addPosAnim(anim, _loginButton, QPointF(640, 380 + 30), QPointF(640, 380),
-                easingCurve, 0);
-    _addOpacityAnim(anim, _exitButton, 0);
-    _addPosAnim(anim, _exitButton, QPointF(460, 380 + 30), QPointF(460, 380),
-                easingCurve, 0);
-
     easingCurve.setType(QEasingCurve::OutBack);
     easingCurve.setOvershoot(2.5);
 
-    /* Checkbox */
-    _addOpacityAnim(anim, _checkboxLabel, 0);
-    _addPosAnim(anim, _checkboxLabel, QPointF(465,300 + 30), QPointF(465,300),
+    /* Buttons */
+    _addOpacityAnim(anim, _loginButton, 0);
+    _addPosAnim(anim, _loginButton, QPointF(715, 423 + 30), QPointF(715, 423),
                 easingCurve, 0);
-    _addOpacityAnim(anim, checkbox, 0);
-    _addPosAnim(anim, checkbox, QPointF(670, 295 + 30), QPointF(670,295),
+    _addOpacityAnim(anim, _exitButton, 0);
+    _addPosAnim(anim, _exitButton, QPointF(716, 0 - 30), QPointF(716, 0),
+                easingCurve, 0);
+    _addOpacityAnim(anim, _exposeButton, 0);
+    _addPosAnim(anim, _exposeButton, QPointF(0, 0 - 30), QPointF(0, 0),
+                easingCurve, 0);
+    _addOpacityAnim(anim, _settingsButton, 0);
+    _addPosAnim(anim, _settingsButton, QPointF(485, 423 + 30), QPointF(485, 423),
+                easingCurve, 0);
+    _addOpacityAnim(anim, _newAccountButton, 0);
+    _addPosAnim(anim, _newAccountButton, QPointF(509, 353 + 30), QPointF(509, 353),
                 easingCurve, 0);
-
-    /* Password Entry */
-    _addOpacityAnim(anim, _labelPassword, delay * 2);
-    _addPosAnim(anim, _labelPassword, QPointF(465,150 + 30), QPointF(465,150), easingCurve, delay * 2);
-    _addOpacityAnim(anim, _entryPassword, delay * 2);
-    _addPosAnim(anim, _entryPassword, QPointF(465,190 + 30), QPointF(465,190),
-                easingCurve, delay * 2);
-
-    /* ID Entry */
-    _addOpacityAnim(anim, _labelID, delay * 3);
-    _addPosAnim(anim, _labelID, QPointF(465,40 + 30), QPointF(465,40),easingCurve, delay * 3);
-    _addOpacityAnim(anim, _entryID, delay * 3);
-    _addPosAnim(anim, _entryID, QPointF(465,75 + 30), QPointF(465,75),
-                easingCurve, delay * 3);
-   
-    /* Logo */
-    _addPosAnim(anim, _logo, QPointF(0,0), QPointF(-200,0),easingCurve, 0);
-
-    /* Background */
-    _addOpacityAnim(anim, _background, 0);
 
     return anim;
 }
@@ -147,88 +106,6 @@ QAbstractAnimation *LoginView::_createExitAnimation(void)
     return anim;
 }
 
-/*!
- * \brief Creates all text entries.
- */
-void LoginView::_createEntries(void)
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    /* Add the entries to the scene */
-    // ID entry
-    _entryID = new LineEdit(LineEdit::Short,this);
-    _entryID->setOpacity(0);
-    _entryID->setPos(QPointF(800, 480));
-
-    // Password entry
-    _entryPassword = new LineEdit(LineEdit::Short,this);
-    _entryPassword->setOpacity(0);
-    _entryPassword->setEchoMode(QLineEdit::Password);
-    _entryPassword->setPos(QPointF(800, 480));
-
-    /* Creating a focus focus order */
-//    connect(_entryID->getEntry()->widget(), SIGNAL(returnPressed()),
-//            _entryPassword, SLOT(selectAll()));
-
-}
-
-/*!
- * \brief Creates all text labels.
- */
-void LoginView::_createLabels(void)
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    QFont font;
-    font.setFamily("Nokia Sans");
-    font.setStyle(QFont::StyleNormal);
-    font.setStyleStrategy(QFont::PreferAntialias);
-    font.setPixelSize(18);
-
-    /* Add the labels to the scene */
-    // ID label
-    _labelID = new TwitterApplicationItem(this);
-    QGraphicsTextItem *labelIDItem =
-        new QGraphicsTextItem(_labelID);
-    labelIDItem->setFont(font);
-    labelIDItem->setDefaultTextColor(QColor(84,83,83,255));
-    labelIDItem->setPlainText(tr("Username or email"));
-    _labelID->setOpacity(0);
-
-    // Password label
-    _labelPassword = new TwitterApplicationItem(this);
-    QGraphicsTextItem *labelPasswordItem =
-        new QGraphicsTextItem(_labelPassword);
-    labelPasswordItem->setFont(font);
-    labelPasswordItem->setDefaultTextColor(QColor(84,83,83,255));
-    labelPasswordItem->setPlainText(tr("Password"));
-    _labelPassword->setOpacity(0);
-}
-
-/*!
- * \brief Creates password checkbox.
- */
-void LoginView::_createCheckbox(void)
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    /* Add the checkbox to the scene */
-    checkbox = new TwitterCheckBox(TwitterCheckBox::RememberMe, QPointF(0, 0), false, this);
-    checkbox->setOpacity(0);
-
-    QFont font;
-    font.setFamily("Nokia Sans");
-    font.setStyle(QFont::StyleNormal);
-    font.setStyleStrategy(QFont::PreferAntialias);
-    font.setPixelSize(18);
-
-    // Checkbox label
-    _checkboxLabel = new TwitterApplicationItem(this);
-    QGraphicsTextItem *checkboxLabelItem =
-        new QGraphicsTextItem(_checkboxLabel);
-    checkboxLabelItem->setFont(font);
-    checkboxLabelItem->setDefaultTextColor(QColor(84,83,83,255));
-    checkboxLabelItem->setPlainText(tr("Remember Me"));
-    _checkboxLabel->setOpacity(0);
-}
-
 /*!
  * \brief Creates login background.
  */
@@ -236,10 +113,10 @@ void LoginView::_createLoginBackground(void)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
-    _background = new TwitterApplicationItem(this);
-    QGraphicsPixmapItem *background = new QGraphicsPixmapItem(_background);
-    background->setPixmap(QPixmap(":images/resources/loginBackground.png"));
-    background->setPos(392,20);
+    m_background = new QGraphicsRectItem(QRectF(0,0,314,480),this);
+    m_background->setPos(800 - m_background->boundingRect().width(),0);
+    m_background->setBrush(QBrush(QColor(255,255,255,100)));
+    m_background->setPen(Qt::NoPen);
 }
 
 /*!
@@ -248,16 +125,28 @@ void LoginView::_createLoginBackground(void)
 void LoginView::_createButtons(void)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
-    _exitButton = new TwitterButton(TwitterButton::Generic, "Exit", this);
+    _exitButton = new TwitterButton(TwitterButton::Close, "",this);
     _exitButton->setOpacity(0);
 
-    _loginButton = new TwitterButton(TwitterButton::Generic, "Login", this);
+    _loginButton = new TwitterButton(TwitterButton::GenericDownRight, "Login", this);
     _loginButton->setOpacity(0);
+    _loginButton->enable(false);
+
+    _exposeButton = new TwitterButton(TwitterButton::Expose, "", this);
+    _exposeButton->setOpacity(0);
+    _exposeButton->setZValue(4.0);
+
+    _settingsButton = new TwitterButton(TwitterButton::LoginSettings,"",this);
+    _settingsButton->setOpacity(0);
+    _settingsButton->enable(false);
+
+    _newAccountButton = new TwitterButton(TwitterButton::NewAccount,"New Account",this);
+    _newAccountButton->setOpacity(0);
 
     _cancelButton = new TwitterButton(TwitterButton::Generic, "Cancel", this);
     _cancelButton->setOpacity(0);
-    _cancelButton->setPos(QPoint(640, 380));
-    _cancelButton->setZValue(2.0);
+    _cancelButton->setPos(QPoint(715, 423));
+    _cancelButton->setZValue(4.0);
 }
 
 /*!
@@ -267,11 +156,37 @@ void LoginView::_createLogo(void)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
-    _logo = new TwitterApplicationItem(this);
-    QGraphicsPixmapItem *logo = new QGraphicsPixmapItem(_logo);
-    logo->setPixmap(QPixmap(":images/resources/logo.png"));
-    logo->setPos((800 - _logo->childrenBoundingRect().width())/2,50);
- }
+    _logo = new QGraphicsPixmapItem(this);
+    _logo->setPixmap(QPixmap(":images/resources/logo.png"));
+    _logo->setPos(35,100);
+}
+
+void LoginView::_createSettings(void)
+{
+    _settingsDialog = new LoginSettings(this);
+    _settingsDialog->setPos(800,0);
+    _settingsDialog->setZValue(3.0);
+}
+
+void LoginView::_createOauthWizard(void)
+{
+    _oauthWizard = new OauthWizard(this);
+    _oauthWizard->setPos(800,0);
+    _oauthWizard->setZValue(3.0);
+
+    connect(_oauthWizard, SIGNAL(newAccount()),SIGNAL(newAccount()));
+}
+
+void LoginView::_createUsersList(void)
+{
+    usersList = new KineticList(KineticList::Vertical, QSizeF(314,270),this);
+    usersList->setScrollBarPolicy(KineticList::Vertical, Qt::ScrollBarAsNeeded);
+    usersList->setPos(486,70);
+    usersList->setZValue(2.0);
+
+    connect(usersList, SIGNAL(selected(bool)), _loginButton, SLOT(enable(bool)));
+    connect(usersList, SIGNAL(selected(bool)), _settingsButton, SLOT(enable(bool)));
+}
 
 /*!
  * \brief Add the opacity Animation
@@ -335,81 +250,10 @@ void LoginView::_addPosAnim(QParallelAnimationGroup *anim,
     }
 }
 
-/*! \brief Gets text from username textbox
- *  \return username username
-*/
-QString LoginView::getUsername(void)
-{
-    QWidget *widget;
-
-    widget = _entryID->getEntry()->widget();
-    return (dynamic_cast<QLineEdit*>(widget))->text();
-}
-
-/*! \brief Sets the username.
- * \param[in] username account's username.
- */
-void LoginView::setUsername(const QString &username)
-{
-    QWidget *widget;
-
-    widget = _entryID->getEntry()->widget();
-    (dynamic_cast<QLineEdit*>(widget))->setText(username);
-}
-
-/*! \brief Gets password from password text box.
- *  \return password returns the password
- */
-QString LoginView::getPassword(void)
-{
-    QWidget *widget;
-
-    widget = _entryPassword->getEntry()->widget();
-    return (dynamic_cast<QLineEdit*>(widget))->text();
-}
-
-/*! \brief Set the password.
- * \param[in] passwd account's password.
- */
-void LoginView::setPassword(const QString &passwd)
-{
-    QWidget *widget;
-
-    widget = _entryPassword->getEntry()->widget();
-    (dynamic_cast<QLineEdit*>(widget))->setText(passwd);
-}
-
-/*! \brief Checks if the remember me checkbox is checked or not.
- * \return isChecked True if remember me is checked or false otherwise.
- */
-bool LoginView::getRememberMe(void)
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    return checkbox->isChecked();
-}
-
-/*! \brief Sets the remember me checkbox.
- * \param[in] remember True to remember or False otherwise.
- */
-void LoginView::setRememberMe(bool remember)
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    checkbox->setChecked(remember);
-}
-
-/*!
- * \brief Emits exitLogin signal if user presses exit button.
- */
-void LoginView::_emitExitLogin(void)
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    emit exitLogin();
-}
-
 /*!
  * \brief Emits login signal if user presses login button.
  */
-void LoginView::_emitLoginAccount(void)
+void LoginView::emitLoginAccount(void)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
     _connecting();
@@ -425,11 +269,8 @@ void LoginView::connectionError()
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
     _deleteLoader();
-    _exitButton->setEnabled(true);
-    _entryID->setEnabled(true);
-    _entryPassword->setEnabled(true);
-    _loginButton->setEnabled(true);
-    checkbox->setEnabled(true);
+    _exitButton->enable(true);
+    _loginButton->enable(true);
     _loginButton->setOpacity(1.0);
     _cancelButton->setOpacity(0);
 }
@@ -459,7 +300,6 @@ void LoginView::_deleteLoader()
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
     delete _loader;
-    setEnabled(true);
 }
 
 /*!
@@ -467,47 +307,26 @@ void LoginView::_deleteLoader()
  */
 void LoginView::_connecting(void)
 {
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
     _loader = new Loader(this);
-    connect(_loader, SIGNAL(finished()), this, SLOT(_deleteLoader()));
-
-    _loader->setZValue(1.0);
-    QGraphicsRectItem *bg = _loader->getBackground();
-    bg->setOpacity(0.6);
-
-    _exitButton->setEnabled(false);
-    _entryID->setEnabled(false);
-    _entryPassword->setEnabled(false);
-    _loginButton->setEnabled(false);
-    checkbox->setEnabled(false);
-
+    _loader->setZValue(3.0);
     _loader->startEntryAnimation();
-}
-
-/*!
- * \brief Emit the signal to load the name from the file or save the name to a file.
- */
-void LoginView::_checked()
-{
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-    emit rememberMe();
+    connect(_loader, SIGNAL(finished()), this, SLOT(_deleteLoader()));
 }
 
 /*!
  * \brief When user hits cancel, this method deletes loader, emits a signal to
  * abort the login, and puts back login button on the screen.
  */
-void LoginView::_endLogin()
+void LoginView::_endLogin(void)
 {
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
-
     emit abort();
     _deleteLoader();
-    _exitButton->setEnabled(true);
-    _entryID->setEnabled(true);
-    _entryPassword->setEnabled(true);
-    _loginButton->setEnabled(true);
-    checkbox->setEnabled(true);
     _loginButton->setOpacity(1.0);
     _cancelButton->setOpacity(0);
 }
+
+void LoginView::_animSettings(void)
+{
+    _settingsDialog->setSelected(usersList->getSelected());
+    _settingsDialog->startAnimation();
+}
