@@ -264,6 +264,11 @@ void TimelineView::setUpdateMessage(const QString &message)
     _entryUpdate->setMessage(message);
 }
 
+void TimelineView::clearText(void)
+{
+    _entryUpdate->clearText();
+}
+
 /*!
  * \brief This slot is called when the user pushes the "update" button.
  * This method starts the loader then sends a signal to the controller to try to login.
